@@ -1,15 +1,17 @@
 __all__ = [
-    'M_BAD_CONNECT',
-    'M_BASE_IMPLEMENTED',
+    'BAD_CONNECT',
+    'BAD_REQUEST',
+    'BASE_IMPLEMENTED',
     'API_VERSION',
     'HEADERS_REQUEST',
     'SITE_RETURNING_URL',
     'FILE_PATH_BAD',
     'CTA',
 ]
-CTA = 'cloudtipsadp'
-M_BAD_CONNECT = 'No service connection.'
-M_BASE_IMPLEMENTED = 'Base class method not implemented.'
+CTA = 'cloudtipsadp: '
+BAD_CONNECT = 'No service connection.'
+BAD_REQUEST = 'BadRequest.'
+BASE_IMPLEMENTED = 'Base class method not implemented.'
 SITE_RETURNING_URL = 'http://127.0.0.1:8000'
 API_VERSION = 'api'
 FILE_PATH_BAD = 'File path missing:'
